@@ -19,7 +19,7 @@ from websockets.exceptions import ConnectionClosedOK
 import colorama
 from tqdm import tqdm
 
-__version__ = '1.2.3'
+__version__ = '1.2.4'
 
 logger = logging.getLogger('websockets')
 logger.setLevel(logging.DEBUG if '--debug' in sys.argv else logging.INFO)
@@ -274,15 +274,21 @@ class Iskra(WebSocketClient):
         await self.send(type='EOT')
 
     async def upload_file(self, progress, client, file):
+        # HACK: stream the file upload
+        #   - is async, so it does not block the websocket ping
+        #   - updates the progress granularly
+        #   - does not http timeout
         from httpx.content_streams import AsyncIteratorStream
         request = client.build_request(
             method='POST',
             url=file['path'],
-            data={'mtime_ns': str(file['mtime_ns'])},
+            headers={'x-mtime-ns': str(file['mtime_ns'])},
             files={'file': open(file['path'], 'rb')},
         )
         data_stream = request.stream.body
 
+        progress.total += len(data_stream) - file['size']
+
         async def stream():
             for chunk in slicing_window(data_stream, size=MEGA_BYTE):
                 progress.update(len(chunk))
